#
# spec file for package findutils
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           findutils
Url:            http://www.gnu.org/software/findutils/
License:        GPL v2 or later
Group:          Productivity/File utilities
Provides:       find 
Obsoletes:      find 
AutoReqProv:    on
PreReq:         %{install_info_prereq}
Version:        4.2.27
Release:        14.22.18
Summary:        GNU find--Finding Files
Source:         findutils-%{version}.tar.gz
Source1:        sysconfig.locate
Source2:        sysconfig.cron-locate
Source3:        cron.daily.updatedb
Source4:        cron.daily.clean_core
Source5:        hu.po
Patch:          findutils-%{version}.diff
Patch2:         warn.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains GNU find and xargs.  The programs comply with
POSIX 1003.2.  They also support additional options, some borrowed from
Unix and some unique to GNU.



Authors:
--------
    David J. MacKenzie <djm@gnu.ai.mit.edu>
    Jan Brittenson <bson@gnu.ai.mit.edu>
    Brian L. Matthews <blm@6sceng.UUCP>
    Mike Rendell <michael@cs.mun.ca>
    James A. Woods <jwoods@adobe.com>
    Jay Plett <jay@silence.princeton.nj.us>
    Tim Wood <tim@toad.com>

%package locate
License:        GPL v2 or later
Summary:        Tool for Locating Files (GNU Findutils Subpackage)
Group:          Productivity/File utilities
Provides:       findutils:/usr/bin/locate
AutoReqProv:    on
PreReq:         %fillup_prereq

%description locate
This package contains the locate program which is part of the GNU
findutils software suite.

You can find files fast using locate.  On installing findutils-locate
an additional daily cron job will be added to the cron system.	This
job will update the files database every night or shortly after
switching on the computer.



Authors:
--------
    David J. MacKenzie <djm@gnu.ai.mit.edu>
    Jan Brittenson <bson@gnu.ai.mit.edu>
    Brian L. Matthews <blm@6sceng.UUCP>
    Mike Rendell <michael@cs.mun.ca>
    James A. Woods <jwoods@adobe.com>
    Jay Plett <jay@silence.princeton.nj.us>
    Tim Wood <tim@toad.com>

%prep
%setup -q
%patch
%patch2
cp %{S:5} po

%build
autoreconf -fi
./configure CFLAGS="$RPM_OPT_FLAGS" \
	    --prefix=/usr --libexecdir=/usr/lib/find --localstatedir=/var/lib \
            --infodir=%{_infodir} --mandir=%{_mandir} \
	    --enable-d_type-optimisation
make
make -C po update-gmo

%install
make install DESTDIR=$RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/var/adm/fillup-templates
mkdir -p $RPM_BUILD_ROOT/etc/cron.daily
install -m 644 %{SOURCE1} $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 644 %{SOURCE2} $RPM_BUILD_ROOT/var/adm/fillup-templates
install -m 755 %{SOURCE3} $RPM_BUILD_ROOT/etc/cron.daily/suse.de-updatedb
install -m 755 %{SOURCE4} $RPM_BUILD_ROOT/etc/cron.daily/suse.de-clean-core

%clean
rm -rf $RPM_BUILD_ROOT

%post locate
%{fillup_only -n locate}
%{fillup_only -sn cron locate}

%post
%install_info --info-dir=%{_infodir} %{_infodir}/find.info.gz

%postun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/find.info.gz

%files
%defattr(-,root,root,755)
%doc README NEWS AUTHORS TODO
/usr/bin/find
/usr/bin/xargs
/usr/share/locale/*/LC_MESSAGES/*.mo
%doc %{_infodir}/find.info*.gz
%doc %{_mandir}/man1/find.1.gz
%doc %{_mandir}/man1/xargs.1.gz

%files locate
%defattr(-,root,root,755)
/etc/cron.daily/*
/usr/bin/locate
/usr/bin/updatedb
/usr/lib/find
%doc %{_mandir}/man1/locate.1.gz
%doc %{_mandir}/man1/updatedb.1.gz
%doc %{_mandir}/man5/locatedb.5.gz
/var/adm/fillup-templates/*

%changelog
* Sun Jan 16 2011 ro@suse.de
- de-fuzz patches to fix build
* Tue Jul 17 2007 schwab@suse.de
- Allow arbitrary characters in file names when cleaning core files
  [#289605].
* Mon Feb 12 2007 schwab@suse.de
- Update Hungarian translation [#244572].
* Thu Mar 23 2006 schwab@suse.de
- Add /sys to UPDATEDB_PRUNEPATHS [#160354].
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 schwab@suse.de
- Fix permissions of cron scripts [#138550].
* Wed Dec  7 2005 schwab@suse.de
- Update to findutils 4.2.27.
* Mon Dec  5 2005 schwab@suse.de
- Drop SELinux support.
* Tue Nov 22 2005 schwab@suse.de
- Update to findutils 4.2.26.
* Wed Oct 19 2005 schwab@suse.de
- Add cifs to the default for PRUNEFS [#129339].
* Wed Oct  5 2005 schwab@suse.de
- Cleanup.
* Sun Sep 25 2005 schwab@suse.de
- Fix warnings.
* Sun Sep  4 2005 schwab@suse.de
- Update to findutils 4.2.25.
* Sun Sep  4 2005 schwab@suse.de
- Don't link libselinux statically.
* Mon Aug  1 2005 mmj@suse.de
- Make updatedb run as an idle io process
* Sun Jun 26 2005 schwab@suse.de
- Make regex syntax compatible to previous versions again.
* Mon Jun 20 2005 schwab@suse.de
- Update to findutils 4.2.23.
* Wed Jun  1 2005 schwab@suse.de
- Rename cron scripts.
* Thu Mar 24 2005 schwab@suse.de
- Update to findutils 4.2.20.
* Wed Mar  9 2005 schwab@suse.de
- Update to findutils 4.2.19 [#71803].
* Sat Feb 19 2005 schwab@suse.de
- Update to findutils 4.2.18.
* Mon Jan 31 2005 schwab@suse.de
- Update to findutils 4.2.15.
* Wed Jan 26 2005 schwab@suse.de
- Update to findutils 4.2.14.
* Mon Jan 24 2005 schwab@suse.de
- Update to findutils 4.2.13.
* Mon Jan 17 2005 schwab@suse.de
- Fix use of next_element.
* Wed Jan 12 2005 schwab@suse.de
- Update to findutils 4.2.11.
* Mon Nov 22 2004 schwab@suse.de
- Update to findutils 4.2.7.
* Mon Nov  1 2004 schwab@suse.de
- Update to findutils 4.2.3.
* Tue Oct 26 2004 schwab@suse.de
- Update to findutils 4.2.2.
* Thu Aug  5 2004 schwab@suse.de
- Update to findutils 4.1.20.
* Thu Jul 29 2004 schwab@suse.de
- Add patch to support d_type.
- Add patch to support POSIX xargs options.
* Mon Mar 15 2004 kukuk@suse.de
- Adjust for new SELinux version
* Fri Dec 12 2003 schwab@suse.de
- Fix file list.
* Tue Nov 11 2003 schwab@suse.de
- Terminate xargs help output with a newline.
* Wed Oct 15 2003 schwab@suse.de
- Cleanup selinux patch.
* Wed Oct 15 2003 ro@suse.de
- link libselinux static
* Tue Oct 14 2003 kukuk@suse.de
- Add selinux patch
- Build not as root
- Fix permissions in RPM filelist
* Fri Oct  3 2003 kukuk@suse.de
- Remove tetex from neededforbuild
* Tue May 13 2003 schwab@suse.de
- Add %%defattr.
- Fix file list.
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Apr  7 2003 schwab@suse.de
- Only delete info entries when removing last version.
* Thu Mar  6 2003 schwab@suse.de
- Fix clean_core cron script [#22758]:
  * use /etc/sysconfig/locate
  * add proper quoting
  * use mtime for finding old cores.
- Fix feedback address.
* Thu Feb  6 2003 schwab@suse.de
- Use %%install_info.
* Tue Dec 10 2002 schwab@suse.de
- Add meta tags to fillup templates.
* Fri Aug  9 2002 bk@suse.de
- findutils-locate: use nice -n 19 for the daily cronjob of updatedb
* Mon Aug  5 2002 schwab@suse.de
- Fix missing newline [#17427].
* Wed Jul 31 2002 schwab@suse.de
- Add PreReq for locate.
* Sun Jun 23 2002 schwab@suse.de
- Make -name conforming to POSIX.
* Fri Mar  8 2002 schwab@suse.de
- Add some documentation [#14733].
* Mon Feb 25 2002 schwab@suse.de
- Fix permissions.
* Wed Feb  6 2002 ro@suse.de
- sysconfig/cron_daily -> sysconfig/cron
* Thu Jan 31 2002 ro@suse.de
- added sysconfig.locate and cron.daily scripts updatedb and
  clean core to locate subpackage
* Thu Jan 31 2002 schwab@suse.de
- Put locate and related programs in their own subpackage.
* Wed Jun  6 2001 schwab@suse.de
- Update to findutils 4.1.7.
* Thu Nov 23 2000 bk@suse.de
- added suse update config macro, was needed for s390
* Tue Oct 24 2000 schwab@suse.de
- Update to findutils 4.1.6.
- Renamed from find.
* Fri Oct 13 2000 schwab@suse.de
- Fix substitution in updatedb script.
* Wed Sep 13 2000 schwab@suse.de
- Fix compilation problem with getline.
- Don't use included regex.
* Wed Sep 13 2000 schwab@suse.de
- Update to findutils 4.1.3.
* Thu Mar 16 2000 schwab@suse.de
- xargs: Move arg_max limit check after environ size check.
* Wed Feb  2 2000 schwab@suse.de
- Fix substitutions in updatedb.
* Mon Jan 17 2000 schwab@suse.de
- /usr/{info,man} -> /usr/share/{info,man}
- Get rid of Makefile.Linux
- Remove some obsolete changes
* Mon Nov 15 1999 kukuk@suse.de
- fix returncode from dostat and dolstat
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Aug 26 1999 schwab@suse.de
- fix "find -false , -name ."
* Fri Dec 18 1998 ro@suse.de
- for glibc: use getline from libc
* Tue Sep  1 1998 ro@suse.de
- fixed macro problems with strcpy,strdup,...
* Thu May 14 1998 florian@suse.de
- added "-s /bin/sh" to further 2 places
- also prune "afs smbfs autofs" filesystems
- fix "find / -xtype l"
- xargs: raise default limit of 20k to 80k for the environment and
  all command parameters
* Mon Nov 10 1997 bs@suse.de
- added "-s /bin/sh" to su command in updatedb (our nobody has /bin/false
  for default shell)
* Sun Apr 13 1997 florian@suse.de
- add bug-fixes from debian and gnu.utils.bugs
- updatedb now supports "--prunefs"
- "mv /usr/libexec/* /usr/lib/find/"
